@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovenian-windows-1250.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: slovenian-windows-1250.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /* By: urska.colner, agenda d.o.o. <urska.colner@agenda.si>, uros kositer, agenda d.o.o. <urosh@agenda.si> */
 
@@ -56,7 +56,6 @@ $strAscending = 'Naraajoe';
 $strAtBeginningOfTable = 'Na zaetku tabele';
 $strAtEndOfTable = 'Na koncu tabele';
 $strAttr = 'Atributi';
-$strAutodetect = 'Samodejno zaznaj';
 $strAutomaticLayout = 'Samodejna postavitev';
 
 $strBack = 'Nazaj';
@@ -136,7 +135,6 @@ $strCreate = 'Ustvari';
 $strCreationDates = 'Datumi za ustvarjeno/posodobljeno/preverjeno';
 $strCriteria = 'Kriteriji';
 $strCroatian = 'Hrvako';
-$strCSVOptions = 'CSV monosti';
 $strCyrillic = 'Cirilica';
 $strCzech = 'eko';
 $strCzechSlovak = 'ekoslovako';
@@ -145,7 +143,6 @@ $strDanish = 'Dansko';
 $strDatabaseEmpty = 'Ime podatkovne baze je prazno!';
 $strDatabaseExportOptions = 'Monosti za izvoz baze podatkov';
 $strDatabaseHasBeenDropped = 'Podatkovna baza %s je zavrena.';
-$strDatabaseNoTable = 'Ta baza podatkov ne vsebuje tabele!!';
 $strDatabase = 'Podatkovna baza';
 $strDatabasesDropped = '%s podatkovne baze so uspeno zavrene.';
 $strDatabases = 'podatkovne baze';
@@ -204,7 +201,6 @@ $strEnglishPrivileges = ' Opomba: Imena MySQL privilegijev so zapisana v anglein
 $strError = 'Napaka';
 $strEstonian = 'Estonsko';
 $strExcelEdition = 'Izdaja za Excel';
-$strExcelOptions = 'Monosti za Excel';
 $strExecuteBookmarked = 'Izvedi izbrano poizvedbo';
 $strExplain = 'Razloi SQL stavek';
 $strExport = 'Izvozi';
@@ -214,7 +210,6 @@ $strExtra = 'Dodatno';
 $strFailedAttempts = 'Neuspeli poizkusi';
 $strFieldHasBeenDropped = 'Polje %s je zavreno';
 $strField = 'Polje';
-$strFieldsEmpty = ' tevec polj je prazen! ';
 $strFieldsEnclosedBy = 'Polja obdana z';
 $strFieldsEscapedBy = 'Polja izognjena z';
 $strFields = 'Polja';
@@ -292,7 +287,6 @@ $strLatexContinued = '(nadaljevanje)';
 $strLatexIncludeCaption = 'Vkljui ime tabele';
 $strLatexLabel = 'Oznai klju';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Monosti za LaTeX';
 $strLatexStructure = 'Struktura tabele __TABLE__';
 $strLengthSet = 'Dolina/Vrednosti*';
 $strLimitNumRows = 'tevilo vrstic na stran';
@@ -535,7 +529,6 @@ $strSort = 'Sortiraj';
 $strSpaceUsage = 'Poraba prostora';
 $strSplitWordsWithSpace = 'Besede so loene s presledkom (" ").';
 $strSQLExportType = 'Vrsta izvoza';
-$strSQLOptions = 'SQL monosti';
 $strSQLParserBugMessage = 'Obstaja monost, da ste v SQL razlenjevalniku naleteli na hroa. Temeljito preglejte poizvedbo in preverite, e so citati pravilni in e se ujemajo. Mono je tudi, da prenaate binarno datoteko, ki je izven podroja besedila citata. Poizvedbo lahko preizkusite tudi na vmesniku ukazne vrstice MySQL. e je strenik MySQL izpisal napako, vam le-ta lahko pomaga pri ugotavljanju teav. e se bodo teave nadaljevale, ali e razlenjevalniku ne uspe tam, kjer vmesniku ukazne vrstice uspe, potem zmanjajte vneeno SQL poizvedbo na tisto poizvedbo, ki povzroa teave in poljite poroilo o napaki skupaj s podatki iz spodnjega odseka IZREZA.';
 $strSQLParserUserError = 'Izgleda, da je v SQL poizvedbi prilo do napake. e je strenik MySQL izpisal napako, vam le-ta lahko pomaga pri ugotavljanju teav.';
 $strSQLQuery = 'SQL-poizvedba';
@@ -681,7 +674,6 @@ $strCopy = 'Copy';  //to translate
 $strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDBCopy = 'Copy database to';  //to translate
@@ -712,21 +704,15 @@ $strGenerate = 'Generate';  //to translate
 $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
-$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIcelandic = 'Icelandic';  //to translate
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
 $strImport = 'Import';  //to translate
 $strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
-$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
-$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
 $strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
-$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
 $strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
 $strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
 $strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
@@ -752,12 +738,10 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLatvian = 'Latvian';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -792,7 +776,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
 $strPasswordHashing = 'Password Hashing';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPersian = 'Persian';  //to translate
@@ -894,7 +877,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -936,7 +919,6 @@ $strSocketProblem = '(or the local MySQL server\'s socket is not correctly confi
 $strSorting = 'Sorting';  //to translate
 $strSpanish = 'Spanish';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -977,16 +959,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1002,7 +980,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1047,4 +1024,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
